#ifndef _APPCHK_SYMBOLS_H
#define _APPCHK_SYMBOLS_H

#include "../elfchk/elfchk.h"

extern int checksymbols(ElfFile *file, int modules);

#endif /* _APPCHK_SYMBOLS_H */
